<?php
/**
 * Input of backlinks monitor
 * @author Artsiom Malkovich (skype: artmalk)
 */


if (file_exists('src/config/credentials.php')) {
    require_once('src/config/credentials.php');
    if (!isset($credentials['username'])) {
        header('Location: install.php');
        exit;
    }
}

session_cache_limiter(false);
session_start();
// define a working directory


$projectFolder = dirname($_SERVER['PHP_SELF']);
if ($projectFolder != '/') {
    $projectFolder = $projectFolder.'/';
}

define('PROJECT_FOLDER', $projectFolder);


define('APP_PATH', __DIR__);
define( 'REDBEAN_MODEL_PREFIX', '\\App\\Model\\');
if( ! ini_get('date.timezone') )
{
    date_default_timezone_set('GMT');
}

// load
require APP_PATH . '/vendor/autoload.php';
require APP_PATH . '/vendor/redbean/rb.php';
require APP_PATH . '/vendor/redbean/ModelFormatter.php';
require APP_PATH . '/src/config/db.php';
require APP_PATH . '/src/config/credentials.php';
require APP_PATH . '/src/translate/eng.php';

// init app
$app = new \SlimController\Slim(array(
    'templates.path'             => APP_PATH . '/src/App/templates',
    'controller.class_prefix'    => '\\App\\Controller',
    'controller.method_suffix'   => 'Action',
    'controller.template_suffix' => 'php',
    'view' => '\Slim\LayoutView',
    'layout' => 'layouts/main.php',
    'db' => $db,
    'credentials' => $credentials
));

$app->addRoutes(array(
    '/'            => 'Index:index',
    '/login'       => 'Login:index',
    '/logout'       => 'Login:logout',
    '/project/edit/1' => 'Project:edit',
    '/project/edit/' => 'Project:edit',
    '/project/add/'  => 'Project:edit',
    '/project/remove/1' => 'Project:remove',
    '/project/dashboard/1' => 'Project:dashboard',
    '/project/backlinks/1' => 'Project:backlinks',
    '/project/settings/1' => 'Project:settings',
    '/project/1/backlinks/import/' => 'Project\\Backlinks:import',
    '/project/1/backlinks/export/' => 'Project\\Backlinks:export',
    '/project/1/backlinks/add/' => 'Project\\Backlinks:add',
    '/project/1/backlinks/remove/' => 'Project\\Backlinks:remove',
    '/project/1/parser/' => 'Project\\Parser:index',
    '/project/1/parser/update/' => 'Project\\Parser:update',
    '/project/parser/link/1' => 'Project\\Parser:link',
    '/parser/cron' =>'Project\\Parser:cron'

));

$app->hook('slim.before.router', function () use ($app) {
    $db = $app->config('db');
    R::setup('mysql:host=' . $db['host'] . ';dbname=' . $db['db'], $db['user'], $db['password']);
    R::freeze(true);

    $formatter = new ModelFormatter();
    RedBean_ModelHelper::setModelFormatter($formatter);
    R::dependencies(array('backlinks' =>array('projects')));

    $loggedin = false;
    if((isset($_SESSION['loggedin']) && $_SESSION['loggedin'] == true) || defined('CRON')) {
        $loggedin = true;
    }
    $app->config('loggedin', $loggedin);

});

function t($a) {
    global $translates;
    if (isset($translates[$a])) {
        return $translates[$a];
    }
    return '';
}

$app->run();
